# Usage

1. [LogViewer API](https://github.com/ARCANEDEV/LogViewer/wiki/4.-Usage#1-logviewer-api)
2. [Entities](https://github.com/ARCANEDEV/LogViewer/wiki/4.-Usage#2-entities)
3. [Helpers](https://github.com/ARCANEDEV/LogViewer/wiki/4.-Usage#3-helpers)

## 1. LogViewer API

#### LogViewer::all()

(Complete description and example)

```php
/**
 * LogViewer::all()
 *
 * @return Arcanedev\LogViewer\Entities\LogCollection
 */
```

#### LogViewer::paginate()

return a paginator object for all logs.

```php
/**
 * LogViewer::paginate($perPage = 30)
 *
 * @param  int  $perPage
 *
 * @return Arcanedev\LogViewer\Entities\LogCollection
 */
```

#### LogViewer::get()

(Complete description and example)

```php
/**
 * LogViewer::get($date)
 *
 * @param  string  $date - Format : YYYY-MM-DD
 *
 * @return Arcanedev\LogViewer\Entities\Log
 */
```

#### LogViewer::entries()

(Complete description and example)

```php
/**
 * LogViewer::entries($date, $level = 'all')
 *
 * @param  string  $date  - Format : YYYY-MM-DD
 * @param  string  $level
 *
 * @return Arcanedev\LogViewer\Entities\LogEntryCollection
 */
```

#### LogViewer::delete()

(Complete description and example)

```php
/**
 * LogViewer::delete($date)
 *
 * @param  string  $date  - Format : YYYY-MM-DD
 *
 * @return bool
 */
```

#### LogViewer::download()

(Complete description and example)

```php
/**
 * LogViewer::download($date, $filename = null, $headers = [])
 *
 * @param  string       $date
 * @param  string|null  $filename
 * @param  array        $headers
 *
 * @return \Symfony\Component\HttpFoundation\BinaryFileResponse
 */
```

#### LogViewer::files()

return list of log files (paths).

```php
/**
 * LogViewer::files()
 *
 * @return array
 */
$files = LogViewer::files();

var_dump($files);

/*
array(
  0 => "{BASE_PATH}\storage\logs\laravel-2015-04-01.log"
  1 => "{BASE_PATH}\storage\logs\laravel-2015-05-01.log"
  2 => "{BASE_PATH}\storage\logs\laravel-2015-06-01.log"
  ...
)
*/
```

#### LogViewer::date()

return list of log files (only dates).

```php
/**
 * LogViewer::dates()
 *
 * @return array
 */
$dates = LogViewer::dates();

var_dump($dates);

/*
array(
  0 => "2015-06-01"
  1 => "2015-05-01"
  2 => "2015-04-01"
  ...
)
*/
```

#### LogViewer::count()

return the number of log files (0 if the log folder is empty)

```php
/**
 * LogViewer::count()
 *
 * @return int
 */
$count = LogViewer::count();

var_dump($count); // >= 0
```

#### LogViewer::total()

return total of all logs entries

```php
/**
 * LogViewer::total($level)
 *
 * @param  string|null $level  -  Log level if you want to filter the entries
 *
 * @return int
 */
$total = LogViewer::total(); // or LogViewer::total('all')

var_dump($total); // >= 0

// To filter by level

$total = LogViewer::total('error');

var_dump($total); // >= 0
```

#### LogViewer::levels()

return all [PSR-3](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-3-logger-interface.md#5-psrlogloglevel) log levels.

```php
/**
 * LogViewer::levels()
 *
 * @return array
 */
$levels = LogViewer::levels();

var_dump($levels);

/*
array(
  "EMERGENCY" => "emergency"
  "ALERT"     => "alert"
  "CRITICAL"  => "critical"
  "ERROR"     => "error"
  "WARNING"   => "warning"
  "NOTICE"    => "notice"
  "INFO"      => "info"
  "DEBUG"     => "debug"
)
*/
```

#### LogViewer::levelsNames()

return all translated log levels.

```php
/**
 * LogViewer::levelsNames($locale)
 *
 * @param  string|null $locale
 *
 * @return array
 */
$levels = LogViewer::levelsNames(); // or LogViewer::levelsNames('auto')

var_dump($levels);

/* If the 'app.locale' == 'en' then the result would be :
array (
  "emergency" => "Emergency"
  "alert"     => "Alert"
  "critical"  => "Critical"
  "error"     => "Error"
  "warning"   => "Warning"
  "notice"    => "Notice"
  "info"      => "Info"
  "debug"     => "Debug"
)
*/
```

> If you want to force the translation to a specified language.

```php
/**
 * LogViewer::levelsNames($locale)
 *
 * @param  string|null $locale
 *
 * @return array
 */
$levels = LogViewer::levelsNames('fr');

var_dump($levels);

/*
array(
  "emergency" => "Urgence"
  "alert"     => "Alerte"
  "critical"  => "Critique"
  "error"     => "Erreur"
  "warning"   => "Avertissement"
  "notice"    => "Notice"
  "info"      => "Info"
  "debug"     => "Debug"
)
*/
```

#### LogViewer::tree()

(Complete description and example)

```php
/**
 * LogViewer::tree($trans = false)
 *
 * @param  bool|false  $trans
 *
 * @return array
 */
```

#### LogViewer::menu()

(Complete description and example)

```php
/**
 * LogViewer::menu($trans = true)
 *
 * @param  bool|true  $trans
 *
 * @return array
 */
```

#### LogViewer::version()

Get the LogViewer's version.

```php
/**
 * LogViewer::version()
 *
 * @return string
 */
$version = LogViewer::version(); // or log_viewer()->version()

echo $version; // x.x.x
```

## 2. Entities

### LogCollection

(Complete description and example)

### Log

(Complete description and example)

### LogEntryCollection

(Complete description and example)

### LogEntry

(Complete description and example)

## 3. Helpers

(Complete description and example)
